@@ -4,7 +4,7 @@ package Test::Class::Moose::Report::Time;
 
 use 5.10.0;
 
-our $VERSION = '0.84';
+our $VERSION = '0.85';
 
 use Moose;
 use Benchmark qw(timestr :hireswallclock);
@@ -12,7 +12,7 @@ use List::Util qw( max );
 use namespace::autoclean;
 
 {
-    my @fields = qw( real user system _children_user _children_system );
+    my @fields = qw( real user system );
     for my $i ( 0 .. $#fields ) {
         has $fields[$i] => (
             is       => 'ro',
@@ -24,14 +24,6 @@ use namespace::autoclean;
     }
 }
 
-has '_iters' => (
-    is       => 'ro',
-    isa      => 'Num',
-    lazy     => 1,
-    default  => sub { $_[0]->_timediff->[5] },
-    init_arg => undef,
-);
-
 has '_timediff' => (
     is       => 'ro',
     isa      => 'Benchmark',
@@ -65,7 +57,7 @@ Test::Class::Moose::Report::Time - Reporting object for timing
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 DESCRIPTION
 
