@@ -8,28 +8,26 @@ use namespace::autoclean;
 
 use 5.10.0;
 
-our $VERSION = '0.84';
+our $VERSION = '0.85';
 
 use Moose::Role;
 use Benchmark qw(timediff timestr :hireswallclock);
 use Test::Class::Moose::Report::Time;
 
 has '_start_benchmark' => (
-    is            => 'ro',
-    isa           => 'Benchmark',
-    lazy          => 1,
-    default       => sub { Benchmark->new },
-    predicate     => '_has_start_benchmark',
-    documentation => 'Trusted method for Test::Class::Moose',
+    is        => 'ro',
+    isa       => 'Benchmark',
+    lazy      => 1,
+    default   => sub { Benchmark->new },
+    predicate => '_has_start_benchmark',
 );
 
 has '_end_benchmark' => (
-    is            => 'ro',
-    isa           => 'Benchmark',
-    lazy          => 1,
-    default       => sub { Benchmark->new },
-    predicate     => '_has_end_benchmark',
-    documentation => 'Trusted method for Test::Class::Moose',
+    is        => 'ro',
+    isa       => 'Benchmark',
+    lazy      => 1,
+    default   => sub { Benchmark->new },
+    predicate => '_has_end_benchmark',
 );
 
 has 'time' => (
@@ -39,6 +37,21 @@ has 'time' => (
     builder => '_build_time',
 );
 
+# If Time::HiRes is available these will be non-integers
+has 'start_time' => (
+    is      => 'ro',
+    isa     => 'Num',
+    lazy    => 0,
+    default => sub { $_[0]->_start_benchmark->[0] },
+);
+
+has 'end_time' => (
+    is      => 'ro',
+    isa     => 'Num',
+    lazy    => 0,
+    default => sub { $_[0]->_end_benchmark->[0] },
+);
+
 sub _build_time {
     my $self = shift;
 
@@ -68,7 +81,7 @@ Test::Class::Moose::Role::HasTimeReport - Report timing role
 
 =head1 VERSION
 
-version 0.84
+version 0.85
 
 =head1 DESCRIPTION
 
@@ -88,6 +101,14 @@ Returns a L<Test::Class::Moose::Report::Time> object. This object
 represents the duration of this class or method. The duration may be "0" if
 it's an abstract class with no tests run.
 
+=head2 C<start_time>
+
+Returns the start time for the report as an epoch value.
+
+=head2 C<end_time>
+
+Returns the end time for the report as an epoch value.
+
 =head1 SUPPORT
 
 Bugs may be submitted at L<https://github.com/test-class-moose/test-class-moose/issues>.
